function drawCoordinatesCross(fid,faceAreaCorr,radiusOfCircumSphere,settings)
%% low-level function
% internal package function
% input structures described in documentation
%
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)

%% correction due to area
if faceAreaCorr < 1
   corrFactor = nthroot(faceAreaCorr,2);
elseif faceAreaCorr < 6
   corrFactor = nthroot(faceAreaCorr,5);
else
   corrFactor = nthroot(faceAreaCorr,15)+nthroot(6,5)-nthroot(6,15);
end

%% coordinates system adjustment
fprintf(fid,'%% ===== Coordinates Cross =====\n');
OriginCoordSystem = settings.OriginCoordSystem;
OriginCoordSystem = OriginCoordSystem + 1.5*radiusOfCircumSphere.*...
   [cos(5*pi/4);sin(5*pi/4)];
VectorCoordSystem = 0.35*radiusOfCircumSphere*settings.VectorsCoordSystem*...
   settings.TransMat3D*[1 0 0; 0 -1 0; 0 0 1];

%% phi coordinate calculation
phiVec = [cos(pi/8) sin(pi/8) 0];
phiVec = 0.25*radiusOfCircumSphere*phiVec*...
   settings.TransMat3D*[1 0 0; 0 -1 0; 0 0 1];

tTemp = linspace(0,pi/8,12);
xTemp = 0.24*radiusOfCircumSphere*cos(tTemp);
yTemp = 0.24*radiusOfCircumSphere*sin(tTemp);
zTemp = zeros(1,12);

pvert = [xTemp' yTemp' zTemp']*settings.TransMat3D*[1 0 0; 0 -1 0; 0 0 1];
mvert = pvert(:,1:2);
pvert = OriginCoordSystem' + pvert(:,1:2);

fprintf(fid,'%% ----- Phi coord ----- \n');
fprintf(fid,['\\draw [-{Stealth [scale=%1.3f]},line width=%1.3f,cap=round,'...
   'black] plot [smooth,tension=1] coordinates { ' sprintf('(%f,%f) ',...
   [pvert(:,1)'; pvert(:,2)']) '};\n'],...
   settings.TikZ_Scale/(11.5+(settings.TikZ_Scale-1)*0.75)*corrFactor,...
   settings.TikZ_Scale/20*sqrt(faceAreaCorr));
fprintf(fid,'\\node[] at (%1.3f,%1.3f) [scale=%1.3f]{$\\varphi$};\n',...
   OriginCoordSystem(1) + 0.82*mean(mvert([1 end],1)),...
   OriginCoordSystem(2) + 0.82*mean(mvert([1 end],2)),...
   1.2*settings.TikZ_Scale/20*sqrt(faceAreaCorr));
fprintf(fid,['\\draw[line width=%1.3f,cap=round, black]'...
   '(%1.3f,%1.3f) -- (%1.3f,%1.3f);\n\n'],...
   settings.TikZ_Scale/20*sqrt(faceAreaCorr),...
   OriginCoordSystem(1), OriginCoordSystem(2),...
   OriginCoordSystem(1) + phiVec(1),...
   OriginCoordSystem(2) + phiVec(2));

%% theta coordinate calculation
thetaVec = [0 sin(pi/12) cos(pi/12)];
thetaVec = 0.25*radiusOfCircumSphere*thetaVec*...
   settings.TransMat3D*[1 0 0; 0 -1 0; 0 0 1];

tTemp = linspace(0,pi/12,8);
zTemp = 0.24*radiusOfCircumSphere*cos(tTemp);
yTemp = 0.24*radiusOfCircumSphere*sin(tTemp);
xTemp = zeros(1,8);

pvert = [xTemp' yTemp' zTemp']*settings.TransMat3D*[1 0 0; 0 -1 0; 0 0 1];
mvert = pvert(:,1:2);
pvert = OriginCoordSystem' + pvert(:,1:2);

fprintf(fid,'%% ----- Theta coord ----- \n');
fprintf(fid,['\\draw [-{Stealth [scale=%1.3f]},line width=%1.3f,cap=round,'...
   'black] plot [smooth,tension=1] coordinates { ' sprintf('(%f,%f) ',...
   [pvert(:,1)'; pvert(:,2)']) '};\n'],...
   settings.TikZ_Scale/(11.5+(settings.TikZ_Scale-1)*0.75)*corrFactor,...
   settings.TikZ_Scale/20*sqrt(faceAreaCorr));
fprintf(fid,'\\node[] at (%1.3f,%1.3f) [scale=%1.3f]{$\\theta$};\n',...
   OriginCoordSystem(1) + 0.82*mean(mvert([1 end],1)),...
   OriginCoordSystem(2) + 0.82*mean(mvert([1 end],2)),...
   1.2*settings.TikZ_Scale/20*sqrt(faceAreaCorr));
fprintf(fid,['\\draw[line width=%1.3f,cap=round, black]'...
   '(%1.3f,%1.3f) -- (%1.3f,%1.3f);\n\n'],...
   settings.TikZ_Scale/20*sqrt(faceAreaCorr),...
   OriginCoordSystem(1), OriginCoordSystem(2),...
   OriginCoordSystem(1) + thetaVec(1),...
   OriginCoordSystem(2) + thetaVec(2));

%% cartesian system
fprintf(fid,'%% ----- Coord arrows ----- \n');
fprintf(fid,['\\draw[-{Stealth [scale=%1.3f]}, line width=%1.3f,'...
   'cap=round, red!75!black] (%1.3f,%1.3f) -- (%1.3f,%1.3f);\n'],...
   2*settings.TikZ_Scale/(11.5+(settings.TikZ_Scale-1)*0.75)*corrFactor,...
   settings.TikZ_Scale/10*sqrt(faceAreaCorr),...
   OriginCoordSystem(1), OriginCoordSystem(2),...
   OriginCoordSystem(1) + VectorCoordSystem(1,1),...
   OriginCoordSystem(2) + VectorCoordSystem(1,2));
fprintf(fid,['\\draw[-{Stealth [scale=%1.3f]}, line width=%1.3f,'...
   'cap=round, green!75!black] (%1.3f,%1.3f) -- (%1.3f,%1.3f);\n'],...
   2*settings.TikZ_Scale/(11.5+(settings.TikZ_Scale-1)*0.75)*corrFactor,...
   settings.TikZ_Scale/10*sqrt(faceAreaCorr),...
   OriginCoordSystem(1), OriginCoordSystem(2),...
   OriginCoordSystem(1) + VectorCoordSystem(2,1),...
   OriginCoordSystem(2) + VectorCoordSystem(2,2));
fprintf(fid,['\\draw[-{Stealth [scale=%1.3f]}, line width=%1.3f,'...
   'cap=round, blue!75!black] (%1.3f,%1.3f) -- (%1.3f,%1.3f);\n\n'],...
   2*settings.TikZ_Scale/(11.5+(settings.TikZ_Scale-1)*0.75)*corrFactor,...
   settings.TikZ_Scale/10*sqrt(faceAreaCorr),...
   OriginCoordSystem(1), OriginCoordSystem(2),...
   OriginCoordSystem(1) + VectorCoordSystem(3,1),...
   OriginCoordSystem(2) + VectorCoordSystem(3,2));

fprintf(fid,'%% ----- Coord labels----- \n');
fprintf(fid,'\\node[] at (%1.3f,%1.3f) [scale=%1.3f]{$x$};\n',...
   OriginCoordSystem(1) + 1.18*VectorCoordSystem(1,1),...
   OriginCoordSystem(2) + 1.18*VectorCoordSystem(1,2),...
   1.2*settings.TikZ_Scale/10*sqrt(faceAreaCorr));
fprintf(fid,'\\node[] at (%1.3f,%1.3f) [scale=%1.3f]{$y$};\n',...
   OriginCoordSystem(1) + 1.18*VectorCoordSystem(2,1),...
   OriginCoordSystem(2) + 1.18*VectorCoordSystem(2,2),...
   1.2*settings.TikZ_Scale/10*sqrt(faceAreaCorr));
fprintf(fid,'\\node[] at (%1.3f,%1.3f) [scale=%1.3f]{$z$};\n\n',...
   OriginCoordSystem(1) + 1.18*VectorCoordSystem(3,1),...
   OriginCoordSystem(2) + 1.18*VectorCoordSystem(3,2),...
   1.2*settings.TikZ_Scale/10*sqrt(faceAreaCorr));

%% miscellaneous comments
xOutCross = radiusOfCircumSphere*0.015*sqrt(2)*[1;1;-1;-1];
yOutCross = radiusOfCircumSphere*0.015*sqrt(2)*[1;-1;-1;1];
comData = [settings.TikZ_Scale/20*sqrt(2)*[1;1],...
   xOutCross(1:2)+OriginCoordSystem(1)...
   yOutCross(1:2)+OriginCoordSystem(2)...
   xOutCross(3:4)+OriginCoordSystem(1)...
   yOutCross(3:4)+OriginCoordSystem(2)];

fprintf(fid,['%%In case of one plane being parallel to screen,'...
   'try use slightly modified following strings. The second string'...
   'is prepared for direction going into plane and the rest two for'...
   'case of direction pointing out of plane. For label, try one of the'...
   'following doublets: (%1.3f,%1.3f), (%1.3f,%1.3f), '...
   '(%1.3f,%1.3f), (%1.3f,%1.3f)\n'],...
   [sqrt(5)*xOutCross(1)+OriginCoordSystem(1)...
   sqrt(5)*yOutCross(1)+OriginCoordSystem(2)...
   sqrt(5)*xOutCross(2)+OriginCoordSystem(1)...
   sqrt(5)*yOutCross(2)+OriginCoordSystem(2)...
   sqrt(5)*xOutCross(3)+OriginCoordSystem(1)...
   sqrt(5)*yOutCross(3)+OriginCoordSystem(2)...
   sqrt(5)*xOutCross(4)+OriginCoordSystem(1)...
   sqrt(5)*yOutCross(4)+OriginCoordSystem(2)]);
fprintf(fid,['%%\\draw[line width=%1.3f,blue!75!black]',...
   '(%1.3f,%1.3f) circle (%1.3f);\n'],...
   settings.TikZ_Scale/20*sqrt(2),...
   OriginCoordSystem(1),...
   OriginCoordSystem(2),...
   radiusOfCircumSphere*0.03);
fprintf(fid,['%%\\node at (%1.3f,%1.3f) '...
   '[circle,fill=blue!75!black,inner sep=%1.3f] {};\n'],...
   OriginCoordSystem(1),...
   OriginCoordSystem(2),...
   radiusOfCircumSphere*0.03);
fprintf(fid,['%%\\draw[line width=%1.3f, blue!75!black]'...
   '(%1.3f,%1.3f) -- (%1.3f,%1.3f);\n'],comData');

end