function farFieldCut2TikZ(hndl,settings)
%% low-level conversion function for plotFarFieldCut()
% internal package function
% input structures described in documentation
%
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)

colMap = colormap('lines');
handleNum = size(hndl,1);

%% Preprocessing
Filling = 0;
if settings.Filling
   Filling = 0.2;
end

RLim = zeros(handleNum,1);
for j = 1:handleNum
   RLim(j) = hndl(j).axes.RLim(2);
end
[RLim, indRLim] = max(RLim(:));

if settings.Coordinates
   if ceil(RLim) == floor(RLim) || RLim - 0.5 == floor(RLim)
      RLim = RLim*1;
   elseif (RLim - floor(RLim) < 0.5)
      RLim = floor(RLim) + 0.5;
   else
      RLim = ceil(RLim);
   end
   
   RGDataLabel = 0:RLim/5:RLim;
   RGData = 0:5;
   TGData= 0:30:330;
   gridLine = [2*ones(1,4) 1];
   LineWidth = 1.25;
   
   gridLineStr1 = sprintf(['\\tikzstyle{gridLine1} = [solid,cap=round,'...
      'line width=0.75,join=round,black]\n']);
   gridLineStr2 = sprintf(['\\tikzstyle{gridLine2} = [dash pattern=on 2 off 2,'...
      'cap=round,line width=0.5,join=round,black!20!white]\n']);
else
   GridColor = hndl(indRLim).axes.GridColor;
   GridOpacity = hndl(indRLim).axes.GridAlpha;
   GridLineWidth = hndl(indRLim).axes.LineWidth;
   LineWidth = hndl(indRLim).farFieldCut.LineWidth;
   
   RGDataLabel = [hndl(indRLim).axes.RTick RLim];
   RGData = RGDataLabel*5/RLim;
   TGData = hndl(indRLim).axes.ThetaTick;
   TGData = TGData(TGData < 360);
   gridLine = 2*ones(1,size(RGDataLabel,2)-1);
   
   gridLineStr1 = [];
   gridLineStr2 = sprintf(['\\tikzstyle{gridLine2} = [solid,cap=round,'...
      'line width=%1.2f,'...
      'opacity=%1.2f,'...
      'join=round,'...
      'color={rgb,255:red,%3.4f;'...
      'green,%3.4f;'...
      'blue,%3.4f}]\n'],GridLineWidth,GridOpacity,floor(255*GridColor));
end
XGData = 5*cos(TGData*pi/180);
YGData = 5*sin(TGData*pi/180);
corrRad = 5/RLim;

%% Strings preparing
if settings.Standalone
   introStr = sprintf([...
      '\\documentclass[tikz]{standalone}\n'...
      '\\usepackage{tikz}\n'...
      '\\usepackage{pgfplots}\n'...
      '\\usepackage{amsmath}\n\n'...
      '%% Converted by AToM2TikZ\n'...
      '\\begin{document}\n']);
   endStr = sprintf([...
      '\\end{tikzpicture}\n'...
      '\\end{document}']);
else
   introStr = sprintf('%% Converted by AToM2TikZ\n');
   endStr = sprintf('\\end{tikzpicture}');
end

beginStr = sprintf('\\begin{tikzpicture}\n');

gridRadStr = sprintf('\\draw [gridLine%d] (0,0) circle (%d);\n',...
   [gridLine;RGData(2:end)]);
gridThetaStr = sprintf('\\draw [gridLine2] (0,0) -- (%1.2f,%1.2f);\n',...
   [-YGData;XGData]);

if RGDataLabel < 1
   gridLabRadStr = sprintf('\\node[] at (0,%1.2f) {$%1.2e$};\n',...
      [RGData-0.2;RGDataLabel]);
else
   gridLabRadStr = sprintf('\\node[] at (0,%1.2f) {$%1.2f$};\n',...
      [RGData-0.2;RGDataLabel]);
end
gridLabThetaStr = sprintf('\\node[] at (%1.3f,%1.3f) {$%d^{\\circ}$};\n',...
   [-1.1*YGData;1.1*XGData;TGData]);

%% Strings printing
fid = fopen([settings.FileName '.tex'],'w+');
fprintf(fid,'%s',introStr);
fprintf(fid,'%s',beginStr);
fprintf(fid,'%% ===== Line styles =====\n');
fprintf(fid,'%s',gridLineStr1);
fprintf(fid,'%s\n\n',gridLineStr2);
fprintf(fid,'%% ===== Theta gridlines =====\n');
fprintf(fid,'%s\n\n',gridThetaStr);
fprintf(fid,'%% ===== Radial gridlines =====\n');
fprintf(fid,'%s\n\n',gridRadStr);
fprintf(fid,'%% ===== Theta labels =====\n');
fprintf(fid,'%s\n\n',gridLabThetaStr);
fprintf(fid,'%% ===== Radial labels =====\n');
fprintf(fid,'%s',gridLabRadStr);

for j = 1:handleNum
   RData =        corrRad*hndl(j).farFieldCut.RData;
   ThetaData =    hndl(j).farFieldCut.ThetaData;
   Color =        colMap(j,:);
   XData =        RData.*cos(ThetaData);
   YData =        RData.*sin(ThetaData);
   
   setStr = sprintf([...
      'color={rgb,255:red,%3.4f;'...
      'green,%3.4f;'...
      'blue,%3.4f},'...
      'line width=%3.4f,'...
      'draw opacity=1,'...
      'fill,'...
      'fill opacity=%3.4f'],...
      255*Color,...
      LineWidth,...
      Filling);
   picStr = sprintf(['\\draw [' setStr '] plot [smooth,tension=1]'...
      'coordinates {' sprintf('\n(%f,%f)',[-YData; XData]) '};\n']);
   
   fprintf(fid,'\n\n%% ===== Plot handle %d =====\n',j);
   fprintf(fid,'%s',picStr);
end
fprintf(fid,'%s',endStr);
fclose(fid);

% additional procedures
if settings.CompileAutomatically && settings.Standalone
   export.advanced.utilities.fileCompile(settings);
end

end