function plotLine2TikZ(hndl,varargin)
%% plot2LineTikZ() serves as interface between MATLAB and LaTeX
% Converts AToM plots into TikZ macros.
%
%  INPUTS:
%   hndl                         structure with particular plot handles
%
%  INPUTS (optional):
%   'Data'                       data structure containing main plot
%                                information
%   'Settings'                   settings structure containing
%                                all or partial parameters
%   'Azimuth'                    specified azimuthal angle (have to be
%                                set together with 'elevation'),
%                                double [1 x 1]
%   'Elevation'                  specified elevational angle (have to be
%                                set together with 'azimuth'),
%                                double [1 x 1]
%   'Correction'                 factor for possible size correction,
%                                
%  Settable parts of Settings structure
%   'CompileAutomatically'       turn on/off automatic compilation,
%                                requires installed pdfLaTeX, possible
%                                evalf danger, boolean [1 x 1]
%   'Coordinates'                turn on/off improved coordinates system,
%                                boolean [1 x 1]
%   'FileName'                   character string with resulting file
%                                name
%   'Filling'                    turn on/off filling of surface bounded by
%                                radiation pattern, boolean [1 x 1]
%   'OriginCoordSystem'          parameter  allows translation of origin of
%                                coordinates system, double [2 x 1]
%   'Standalone'                 sets file to be standalone or not, 
%                                boolean [1 x 1]
%
%  SYNTAX:
%   plotLine2TikZ(hndl,___)
%
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)

p = inputParser;
defaultCompileAutomatically =    true;
defaultCoordinates =             false;
defaultFileName =                ['AToM2TiKZ' num2str(now)];
defaultFilling =                 false;
defaultStandalone =              true;

p.addParameter('CompileAutomatically', defaultCompileAutomatically,...
   @(CompileAutomatically) validateattributes(CompileAutomatically,...
   {'logical'}, {'nonempty','size',[1 1]}));
p.addParameter('Coordinates', defaultCoordinates,...
   @(Coordinates) validateattributes(Coordinates,...
   {'logical'}, {'nonempty','size',[1 1]}));
p.addParameter('FileName', defaultFileName,...
   @(FileName) validateattributes(FileName,...
   {'char'}, {'nonempty'}));
p.addParameter('Filling', defaultFilling,...
   @(Filling) validateattributes(Filling,...
   {'logical'}, {'nonempty','size',[1 1]}));
p.addParameter('Standalone', defaultStandalone,...
   @(Standalone) validateattributes(Standalone,...
   {'logical'}, {'nonempty','size',[1 1]}))

p.parse(varargin{:})
settings.CompileAutomatically =  p.Results.CompileAutomatically;
settings.Coordinates =           p.Results.Coordinates;
settings.FileName =              p.Results.FileName;
settings.Filling =               p.Results.Filling;
settings.OpenAfter =             true;
settings.Standalone =            p.Results.Standalone;

export.advanced.farFieldCut2TikZ(hndl,settings);

end