%% TikZ Conversion Functions Example
% Example of usage of plot conversion to TikZ macros.
%
% AToM2TikZ expansion, beta version
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)
clc;
clear;
close all;

% Load of object of interest and creation of mesh.
file = 'horn.bdf';
[vert, ~, faces_b,~,~] = models.utilities.meshPublic.importNastran(file);
Mesh =  models.utilities.meshPublic.getMeshData2D(vert,faces_b);

% Evaluation of first five characteristic modes.
ka = 1;
[~, BF, OP] = evaluateOperators(Mesh.nodes, Mesh.connectivityList,...
   models.utilities.converter.k0tof0(ka/Mesh.normDistanceA), []);
[I, ~] = eigs(imag(OP.Z), real(OP.Z), 5, 'sm');

% Computation of far field structure.
theta = linspace(0, pi, 35);
phi = linspace(0, 2*pi, 70);
farfield = results.calculateFarField(Mesh, 1e8, 'basisFcns', BF,...
   'theta', theta, 'phi', phi, 'iVec', I(:,2));

% Plotting of far field.
hndl = results.plotFarField('theta',theta,'phi',phi,...
   'farField',farfield.D);
hndl.type = 'farField';

%% Simplest Way
% Data are converted with default settings. 'FileName' is optional parameter,
% here is used for better distinguishability of resulting files.
[data,settings] = export.plot2TikZ(hndl,...
   'FileName','far_field_3D');

%% Angle Settings
% View angles are specified in this example. If desired view is specified, both
% values azimuth and elevation have to be set at once. 'Colorbar' turns on
% colorbar on the right side of picture.
export.plot2TikZ(hndl,...
   'Azimuth',-130,...
   'Elevation',30,...
   'FileName','far_field_3D_angles',...
   'CoordinatesCross',true,...
   'Colorbar',true);

%% Opacity Settings
% The example of scalar opacity settings. Be aware of automatically disabled
% direct visbility compression in results.
export.plot2TikZ(hndl,...
   'TikZ_Opacity',0.8,...
   'Compression',true,...
   'FileName','far_field_3D_opacity');

%% Motion Pictures
% Animated far field plot in elevation view. Azimuthal angle is fixed at value
% -130 degrees.
azimuth = -130;
elevation = 0:15:345;
export.animatePlot2TikZ(hndl,azimuth,elevation,...
   'FileName','far_field_3D_animate',...
   'CoordinatesCross',true)

% TikZ coordinates scaling, compression ratio