%% TikZ Conversion Functions Example
% Example of usage of plot conversion to TikZ macros.
%
% AToM2TikZ expansion, beta version
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)
clc;
clear;
close all;

% Load of object of interest and creation of mesh.
file = 'horn.bdf';
[vert, ~, faces_b,~,~] = models.utilities.meshPublic.importNastran(file);
Mesh =  models.utilities.meshPublic.getMeshData2D(vert,faces_b);

% Evaluation of first five characteristic modes.
ka = 1;
[~, BF, OP] = evaluateOperators(Mesh.nodes, Mesh.connectivityList,...
   models.utilities.converter.k0tof0(ka/Mesh.normDistanceA), []);
[I, ~] = eigs(imag(OP.Z), real(OP.Z), 5, 'sm');

% Computation of far field structure.
theta = linspace(0, pi, 90);
phi = linspace(0, 2*pi, 180);
farfield = results.calculateFarField(Mesh, 1e8, 'basisFcns', BF,...
   'theta', theta, 'phi', phi, 'iVec', I(:,2));

% Preparation of plotting.
phiCut = pi/2;
hndl = results.plotFarFieldCut('theta', theta, 'phi', phi, ...
   'farField', farfield.D, 'phiCut', phiCut);
thetaCut = pi/2;
hndl2 = results.plotFarFieldCut('theta', theta, 'phi', phi, ...
   'farField', farfield.D, 'thetaCut', thetaCut);

%% Single Plot
% This example shows basic plot without filling and with coordinates taken from
% handle figures.
export.plotLine2TikZ(hndl,...
    'fileName','far_field_2D',...
    'Filling',false,...
    'Coordinates',false);
 
%% Multi Plot
% In case of multiple handles in column vector, function draws all these
% radiation patterns into one picture. Parameter 'Coordinates' sets enhanced
% coordinates system.
export.plotLine2TikZ([hndl; hndl2],...
    'filename','far_field_2D_double',...
    'CompileAutomatically',true,...
    'Coordinates',true,...
    'Filling',true)