%% TikZ Conversion Functions Example
% Example of usage of plot conversion to TikZ macros.
%
% AToM2TikZ expansion, beta version
%  2020, Vojtech Neuman, neumavo1@fel.cvut.cz (2020)
clc;
clear;
close all;

% Acquisition of mesh structure from .nas file.
file = 'horn.bdf';
[vert, ~, faces_b,~,~] = models.utilities.meshPublic.importNastran(file);
Mesh =  models.utilities.meshPublic.getMeshData2D(vert,faces_b);

colorMap = results.colors.colorLib.paired12.getColorMap(1);

% Visualisation of meshed object, options.showTriangles = true is required.
options.showTriangles = true;
hndl = results.plotMesh(Mesh,'options',options);
hndl.type = 'mesh'; 

% Specification of colour settings.
hndl.triangles.FaceColor = 'flat';
hndl.triangles.CDataMapping = 'scaled';
hndl.triangles.FaceVertexCData = ones(Mesh.nTriangles,1).*colorMap(11,:);

%% Few Settings
% Converted plot contains shading feature for better perspective view.
export.plot2TikZ(hndl,...
    'FileName','mesh_plot_3D',...
    'TikZ_Scale',10,...
    'Azimuth',-120,...
    'Elevation',30,...
    'CoordinatesCross',true);
 
%% More Colours
% If desired, user can set different colours for particular triangle. In this
% example is each side of trash bin colored with different colour.

hndl.triangles.FaceVertexCData(1:110,:) = ones(110,1).*colorMap(1,:);
hndl.triangles.FaceVertexCData(111:331,:) = ones(221,1).*colorMap(3,:);
hndl.triangles.FaceVertexCData(332:441,:) = ones(110,1).*colorMap(5,:);

export.plot2TikZ(hndl,...
    'FileName','mesh_plot_3D_recycle',...
    'TikZ_Scale',10,...
    'TikZ_Shading',false);